@@ -1,6 +1,7 @@
 #[cfg(test)]
 mod tests {
     use std::sync::Arc;
+    use simple_optimization::Polling;
     // For random element we want to reruns tests a few times.
     const CHECK_ITERATIONS: usize = 100;
 
@@ -121,8 +122,7 @@ mod tests {
                 [0f64..10f64, 5f64..15f64, 10f64..20f64],
                 simple_function,
                 None,
-                None,
-                Some(19.),
+                Some(Polling::new(false, Some(19.))),
                 1000,
             );
             assert!(simple_function(&best, None) < 19.);
@@ -135,8 +135,7 @@ mod tests {
                 [0..10, 5..15, 10..20],
                 simple_function_u8,
                 None,
-                None,
-                Some(15.),
+                Some(Polling::new(false, Some(15.))),
                 1000,
             );
             assert!(simple_function_u8(&best, None) < 18.);
@@ -155,8 +154,7 @@ mod tests {
                 ],
                 complex_function,
                 None,
-                None,
-                Some(-18.),
+                Some(Polling::new(false, Some(-18.))),
                 1000,
             );
             assert!(complex_function(&best, None) < -17.);
@@ -169,8 +167,7 @@ mod tests {
                 [0..10, 5..15, 10..20, 15..25, 20..30],
                 complex_function_u8,
                 None,
-                None,
-                Some(-17.),
+                Some(Polling::new(false, Some(-17.))),
                 1000,
             );
             // -17.001623699962504
@@ -186,8 +183,7 @@ mod tests {
                 [0..255],
                 boundary_function,
                 images.clone(),
-                None,
-                Some(0.),
+                Some(Polling::new(false, Some(0.))),
                 1000,
             );
             // Since we have 15 lines of 5 the error values are: 0*15, 1*15, 2*15, 3*15, 4*15, 5*15
@@ -203,8 +199,7 @@ mod tests {
             [0f64..10f64, 5f64..15f64, 10f64..20f64],
             simple_function,
             None,
-            None,
-            Some(18.),
+            Some(Polling::new(false, Some(18.))),
             [10, 10, 10],
         );
         assert_eq!(simple_function(&best, None), 15.);
@@ -215,8 +210,7 @@ mod tests {
             [0..10, 5..15, 10..20],
             simple_function_u8,
             None,
-            None,
-            Some(18.),
+            Some(Polling::new(false, Some(18.))),
             [10, 10, 10],
         );
         assert_eq!(simple_function_u8(&best, None), 15.);
@@ -233,8 +227,7 @@ mod tests {
             ],
             complex_function,
             None,
-            None,
-            Some(-19.),
+            Some(Polling::new(false, Some(-19.))),
             [4, 4, 4, 4, 4], // 4^5 = 1024 ~= 1000
         );
         assert!(complex_function(&best, None) < -14.);
@@ -245,8 +238,7 @@ mod tests {
             [0..10, 5..15, 10..20, 15..25, 20..30],
             complex_function_u8,
             None,
-            None,
-            Some(-14.589918826094747),
+            Some(Polling::new(false, Some(-14.589918826094747))),
             [4, 4, 4, 4, 4], // 4^5 = 1024 ~= 1000
         );
         assert_eq!(complex_function_u8(&best, None), -14.589918826094747);
@@ -260,8 +252,7 @@ mod tests {
                 [0..255],
                 boundary_function,
                 images.clone(),
-                None,
-                Some(0.),
+                Some(Polling::new(false, Some(0.))),
                 [255],
             );
             assert_eq!(boundary_function(&best, images.clone()), 0.);
@@ -277,8 +268,7 @@ mod tests {
                 [0f64..10f64, 5f64..15f64, 10f64..20f64],
                 simple_function,
                 None,
-                None,
-                Some(17.),
+                Some(Polling::new(false, Some(17.))),
                 100.,
                 1.,
                 simple_optimization::CoolingSchedule::Fast,
@@ -295,8 +285,7 @@ mod tests {
                 [0..10, 5..15, 10..20],
                 simple_function_u8,
                 None,
-                None,
-                Some(16.),
+                Some(Polling::new(false, Some(16.))),
                 100.,
                 1.,
                 simple_optimization::CoolingSchedule::Fast,
@@ -319,8 +308,7 @@ mod tests {
                 ],
                 complex_function,
                 None,
-                None,
-                Some(-20.),
+                Some(Polling::new(false, Some(-20.))),
                 100.,
                 1.,
                 simple_optimization::CoolingSchedule::Fast,
@@ -337,8 +325,7 @@ mod tests {
                 [0..10, 5..15, 10..20, 15..25, 20..30],
                 complex_function_u8,
                 None,
-                None,
-                Some(-19.),
+                Some(Polling::new(false, Some(-19.))),
                 100.,
                 1.,
                 simple_optimization::CoolingSchedule::Fast,
@@ -357,8 +344,7 @@ mod tests {
                 [0..255],
                 boundary_function,
                 images.clone(),
-                None,
-                Some(0.),
+                Some(Polling::new(false, Some(0.))),
                 100.,
                 1.,
                 simple_optimization::CoolingSchedule::Fast,
